@@ -4,6 +4,10 @@
 use_test :<%= testing_framework %>
 use_template_engine :<%= template_engine %>
 
+# If you need to use dependency immediately in this file you must add :immediate => true 
+# to dependency definition:
+# dependency "merb-slices", :immediate => true
+#
 # Specify a specific version of a dependency
 # dependency "RedCloth", "> 3.0"
 
@@ -32,7 +36,7 @@ Merb::Config.use { |c|
   c[:use_mutex]           = false,
   c[:session_store]       = 'cookie',
   c[:session_id_key]      = '_<%= base_name  %>_session_id',
-  c[:session_secret_key]  = '<%= SHA1.new(rand(100000000000).to_s).to_s %>',
+  c[:session_secret_key]  = '<%= Digest::SHA1.hexdigest(rand(100000000000).to_s).to_s %>',
   c[:exception_details]   = true,
   c[:reload_classes]      = true,
   c[:reload_templates]    = true,
